+++
title = "Lessons learned at satRdays Amsterdam 2018"
date = "2019-01-04"
tags = ["amsterdam"]
categories = ["conference"]
banner = ""
author = "Roel M. Hogervorst"
+++

In this blogpost we look back at our [satRday in Amsterdam 2018](https://amsterdam2018.satrdays.org/).
We pull out the lessons we learned and which could help you when you are organizing a satRday.
We will definitely use this document for our next satRday. This document is not
meant to be a full on evaluation of the entire event, we feel those will
never be read.  This is a highly skimmable
document with the most important pointers for new and returning organizers.
If you are only interested in the steps for organizing a conference skip to the
important steps [further down.](#important-steps-for-organizing-a-satrdaysE)

In this post you will find:

- What are satRdays, why are we organzing this and what is it like?
- Important steps in organizing a SatRdays conference.


# What makes satRdays?

SatRdays are community led events that celebrate R and its useRs.
In general a satRdays is slightly larger than a typical meetup but
smaller than a multi day conference. SatRdays are one day events and the tickets
should cost less than a full day of minimal wage work. The goal is to have a
small gathering of r-users and speakers. Think of it like multiple meetups
stacked on top of each other into 1 day, a Saturday.

Our satRday in Amsterdam was a great success. We had 13 talks and very happy
useRs. The event ran very smoothly and almost everything went according to plan.
We had space for 100 attendees, and
every place was used. The main event was indeed on Saturday 1st but
we added a tutorial day on Friday and also an open source day on Sunday.
We wanted a tutorial day, so that novice R-users
(for a great description of skill levels see [^1]) would feel empowered
to enjoy and be part of the next day.
We added the open source day because we
had the event location for the entire weekend, and we figured we should capitalize on
the empowerment and energy created on the main day (which really worked!).



# Important steps for organizing a SatRdays
*It is really boring to describe every step in chronological order so here
are the main points you might consider when you want to organize a satRday
and how we solved those points.*


## Finding a committee
You and your co-organizers do not only divide the tasks but the members of your committee
are also your entrance to speakers, companies and your audience. You need to think about
setting up general communication, sharing of documents etc. to setup the event.

We were brought together by our Gymleader / pokemaster Vincent. Vincent invited
rladies, his colleague, and me (Roel) to think about organizing the event.  We used the general satRdays
slack channel, and google drive to share documents. Although we all live in the
Netherlands we live and work around the country. We used skype for most of our weekly
updates. Through our mutual contacts, via Rladies and the satRdays promotion we
were able to get enough speakers in sessionize to fill all our speaker spots.

## Size of the event
How many people do you want at your event? This determines your location or
your location sets a limit to the number of attendees. With bigger size comes
bigger (financial) risk. If the whole thing fails, someone has to pay the costs.
Also consider the event flow: do you keep to 1 track or will there be parallel
speakers? If you do, people have to walk from one place to another, and talks
that run out of time
hold up everyone who wants to attend a different talk. If you choose a single
track, you will have to think about the level of the talks. A mix of talks that cater to an audience of novices
and experts. 

We set the upper limit of attendees to 100, because that fitted in the location.
We decided on a single track, mostly because it was our first time and we wanted to keep it simple. 
We could have divided up the room into 2 but
decided not to. 
In fact there were many people, who considered themselves advanced useRs,
who said they would never had gone to the
dplyr talk if they had an other option, but they were pleasantly surprised to have
learned new stuff.


## How to find help
Talk to people, over Slack, email, phone or read in the [knowledgebase](https://knowledgebase.satrdays.org/).


## Picking a date
Picking a date can be difficult but there are a few guidelines. There can not be
two satRdays at the same time in the same geographical area. If there is a
satRday in Brussels you can not have one the next week in Amsterdam (they are both in Northwest Europe).
You also need to think about other events: UseR!, Statistics conferences or
other R/data science events, because those events draw from the same pool of attendees and speakers.

We picked the date of September first, which was not ideal. Because it was summer holiday, we had trouble
contacting sponsors, promoting the event and finding speakers. We would
generally advise against organizing such an event in the summer holidays.


## How to find speakers
It's nice if you have a better known speaker (keynote) for your event, that
speaker will draw more people and possibly other speakers. You can contact speakers and/or you send out
a call for papers. Don't forget to call upon people you know (even only vaguely).

We set up a list of potential speakers that we wanted to see. We had arranged
for Mara Averick to
be the keynote speaker very early on so that helped us a lot. We used the
Rladies network to contact potential speakers and used common slack groups,
Twitter and even Linkedin to connect to speakers. We also set up a 'Call for
speakers' via sessionize. This system allowed us to receive and order
the responses that people send in. We also used sessionize to send our speakers
information, confirmation and modify their talk length. This worked really well.


## How to promote the event
You do not organize this event solely for yourself to listen to your favorite speakers,
you want other people to enjoy those speakers as well. Think about your
audience, who do you
want to reach? students, professionals? on what level? in what field?

Our attendees learned about our event through Linkedin, Twitter but also through
announcements in meetups. In the future we could send messages to other R user
groups, student associations, and professional organizations. Our audience was
mostly beginners and novices with a few advanced useRs as well.


## How to find sponsors
The satRdays are supposed to be cheap. But even so it helps if there is some
money other than the money from the ticket sales. You can make list of things
that can be sponsored: stickers, video, website advertisement, breakfast, goodies,
posters, lunch, drinks etc. 

Sponsoring is a trade between a company and your
event. You make the company look good and they give you money.
Make that trade CONSCIOUSLY, SatRdays has strong ideas about inclusivity,
diversity and creating a safe space to learn. The companies that advertise on
your event need to reflect those ideas too. A company that behaves in way that is not
in line with our code of conduct is not a good choice for sponsor.

We had a hard time finding sponsors, many spokespersons in companies were
unavailable because of
holidays. To help us in negotiations we made a list of things to sponsor:
video editing, food, advertisement on the webpage etc. We did not want posters,
banners or promoted talk at the event, because we felt that no one really wanted
to listen to promoted talks and posters and banners wouldn't really work.
We did have a sponsor that was unfit in hindsight.

# What did our visitors think of the event?
A week after the event we send evaluation forms to our
attendees and also spread it via Twitter. Unfortunately we only got 10% response
rate. During the event we spoke to many attendees and the general sentiment was
great! They seemed very happy, which was a pleasure to see. We highlight a few
questions we asked our attendees. The price (EUR 40,00) was right for most people.
Most attendees payed for themselves, some were sponsored by their employer.

## Who came to our event?
We tried to estimate the R skill level of our attendees. Because many people
are having a hard time placing themselves in a beginner, novice, intermediate,
expert categorization, we thought up a different classification: (1) just starting,
(2) using functions from packages, (3) building a package and (4) maintaining
multiple packages.

Which in hindsight might be a combination of skills and not really a scale.
Most of the attendees said they used
functions, we will classify them as 'users', 14% of the respondents create their
own packages which we will classify as 'builders'. some are completely new to R.
It was a good mix of the general useRs we think.

## Why do attendees come to this event?
Many attendees came for personal
development, but also for the content or specifically for the speakers.

## Where did the attendees come from?
We aimed for a local presence, which worked out, because some respondents actually
answered Amsterdam, instead of a country.  Most attendees came from the Netherlands,
but there were also people from neighboring countries such as Germany, and Belgium.
Some people came from further away.

## How did people hear from our event? 
Attendees had heard from the event through
newsletters, work, meetups, the SatRdays network, R-ladies but mostly through
Linkedin and Twitter.

## What did the attendees think of the event?
The sentiment about the entire event was very positive.
Attendees especially liked the 10 minute lightning rounds, the speakers in
general and the diversity of topics. And they liked meeting other people.

Attendees also pointed out some things they did not like.
We started too early and there were too many talks at the end.


# Closing remarks
We had a great time along with the attendees and speakers.
We hope to organize a similar event next year, and we want to thank everyone.

Tess Korthout, Steven Nooijen, Ilse Pit, Vincent Warmerdam, Janine Khuc & Roel Hogervorst


See the videos here: https://www.youtube.com/watch?v=rFzfUdCKhwk

[^1]: https://en.wikipedia.org/wiki/Dreyfus_model_of_skill_acquisition

