+++
title = "How to Organize a SatRday (LA) Conference"
date = "2020-01-27"
tags = ["losangeles", "2019"]
categories = ["conference"]
author = "Amy Tzu-Yu Chen"
+++

*This post was originally shared on [Amy's blog](https://amy17519.me/post/2019/04/25/how-to-organize-a-satrday-la-conference/).*


With lots of help, I organized the inaugural SatRday LA conference at UCLA Alumni Center on April 6, 2019. I promised myself (and publicly on a Slack —> I guess this is really why I am posting now) to write a blogpost about my organizing experience. First of all, what I am about to talk about are just how we decided to organize a SatRday and you are free to organize SatRday in any way you like, as long as you don’t violate [SatRday Org’s important requirements](https://knowledgebase.satrdays.org/organising/).

Some numbers about SatRday LA 2019:

- 206 people registered and 180 people showed up
- 9 talks, 3 workshops, and 2 keynotes
- $35 for Professional, $15 for Student
- 14 students were sponsored by another attendee
- 127+67 = 194 commits on SatRday LA repos
- 15 tweets on [@satRdays_org](https://twitter.com/satRdays_org)

If you are interested what happened at SatRday LA 2019, go to the following links:

- [Conference Site](http://losangeles2019.satrdays.org)
- [Talk Materials](https://github.com/satRdays/losangeles/tree/master/2019)
- [Recorded Talks](https://www.youtube.com/playlist?list=PLQRHxIa9tfRvXYyaVS77zshvD0i17Y60s)

If you are interested in organizing a SatRday :hushed: , read on!
 

## Motivation
There used to be regular, sizable R meetups in (West) LA, where I learned about R’s capabilities and made a lot of friends. Also, we haven't had any R-focused conferences in SoCal since useR! 2014 at UCLA. I personally feel spoiled by past organizers, and thought it was time for someone to step up and start organizing R events in West LA. After useR! 2018, this thought became stronger.

I first heard about SatRday from my coworker, Gergely Daróczi, who also happen to be the guy who organized the very first SatRday in Budapest, Hungary (You can read about his experience [here](http://datascience.la/how-to-organize-a-satrday-conference-v0-1/). It did not take me long to commit to organizing SatRday LA since it matches what I look for in an opensource R event: :white_check_mark: R-focused , :white_check_mark: affordable, :white_check_mark: inclusive and accessible.

Before I start the organizing process, I set some additional requirements for SatRday LA. First, I hope that this conference covers diverse topics and "paradigms" in #rstats. Although it is only an one-day conference and we do not have resources to have a lot of tracks, I hope attendees at different levels can learn something new/different at the event. Second, I want to ensure that I prepare enough branding materials and a very basic workflow for future SatRday LA organizers. That just means I will have to be super organized and document everything :grin:. I enocourage you to do the same if you want SatRday to run in your city _annually_. Going that extra mile for every detail can help future organizers save a lot of time and money.


## Organizing Process

#### Pick a Date and Venue
Step one is to sign up on SatRday's [event calendar](https://github.com/satRdays/eventscalendar). I went through a quick process of elimination and picked Q2 2019. You would need to pick a date range that would not conflict with other local and international R or data science conferences. Also, try not to pick summer or spring break because it would be hard to get students in those times.

Organizing an affordable conference means that you need to be cautious about how much things cost ahead of time. The cost of venue could vary a lot, and directly links to your event ticket prices and how many sponsors you need to get. So, we decided to find a venue first. I selfishly wanted to organize the first SatRday LA at UCLA because it is my alma mater and it is close to my home :no_mouth: ... Fortunately, we found UCLA Alumni Association as our venue partner, and I am forever grateful for their support!

In addition to cost, it is important to lock a date with your venue early so that you have more date options. The venue may not have the date you need later, and our options are even fewer than other events because it has to be a Sat(u)Rday.

#### Logo
A lot of SatRday organizers make their own logo, usually a variation/extension of the [SatRday org logo](https://github.com/satRdays/assets/blob/master/satRday%20Logo.png). Logos are important if you want to run SatRday annually in your city, and also come in handy for marketing and making swags. 

What’s special about this logo is that the it's not quite a R hexagonal shape. The top of the logo is a horizontal line instead of an angle :flushed: . Gergely said it was a "mistake" made from the start. I thought it is special that we have a slightly different hexagon logo so decided to keep the shape. Other organizers, such as [SatRday Berlin](https://github.com/satRdays/berlin2019/blob/master/static/img/flyer.jpg), chose to rotate and "correct"" the hexagon. 

#### Organizing Committee
My advice is to keep organizing committee small (2~3 ppl) and make sure they understand the amount of work involved in the organizing process. Also, try to have a constant channel for instant communication with all organizers. In our case, SatRday's slack workspace was great and I could get a response from my co-organizers within a day. Overall, we had less than 5 short meetings.

#### Program Committee
You do not have to separate Program and Organizing Committees, but that was my choice. Separating Program committee and organizers could ensure that each can focus on their task more. Organizers could be new useRs or people who simply want to contribute to local R community. On the other hand, Program Committee members are experienced and _critical_ useRs. That is important, especially if we want to have a diverse range of topics and let people present different ways of using R. We aimed to have 5~10 committee members, and we had 6 at the end. Special thanks to Szilard for connecting me with most program committee members. And thanks to all committee members for accepting my invitation without hesitation. Our Program Committee had 0 meeting and discussed everything on slack. 

You do not need to worry about sending submissions and designing rubrics for Program Committee. SatRday organizers can use Sessionize for free to manage submissions, which definitely saved us a lot of time.

#### Budgets and Finance
After being spoiled at many conferences and local events, I want to spoil SatRday LA attendees as well. However, SatRday is an affordable event and we need to spend money wisely. 

Before setting the ticket price, we listed out essential items and desired items for the event. Essential items are venue, food, T-shirts (yes..), badges, and hex stickers etc. Desired items are videography, swags, fancy badges, beverages, banners and table cloth etc. First, we got a preliminary quote for each item. Then, we figured out how much we want to get from ticket sales and how much we want to raise. We planned to pay for all essential items from sponsorships and donations. Ticket sales would be used to pay for desired items. 

IMPORTANT: keep all receipts and document everything related to :moneybag: . These will be useful for 1) for future budget planning 2) if you ever need to deal with tax.

#### Keynote and Call for Presentations
We made a list of desired keynote speakers and let Program Committee vote on the speakers. Then, we invited keynote speakers in the order of poll result. Remember not to invite everyone at the same time to avoid the awkward situation of having too many keynotes. I kept at most 3 pending invitations.

Give people enough time to submit their presentations (~5 weeks for SatRday LA 2019). Equally important, give Program Committee enough time to review submissions (2~3 weeks for SatRday LA 2019). During CfP, we marketed SatRday LA and encouraged people to submit at local meetups and academic institutions. Towards the end of CfP deadline, I sent out emails to useRs who might have something to submit.

#### Sponsors
Now, I will share how we raised money for SatRday LA 2019. First, try to research if you can get help from major R groups such as RStudio and RConsortium. SatRday Org is currently working on making these funds more accessible to organizers. Details to come! Second, list out companies that use R or want to hire useRs. It usually takes more time and process to get sponsorships from big companies so start with those first. You may tier your sponsorships, but SatRday LA 2019 did not.

#### Marketing
I would like to thank community organizers of R User Groups for helping us market SatRday LA 2019 on not only their [website](https://laocr.org), but also in every meetup. In addition to local meetups, we also reached out to schools (usu. Dept of Statistics) and tweeted regularly.

#### Videography
SatRday Org is also planning on making this service more accessible for all organizers. Stay tuned! SatRday LA 2019 talked to many videographers before the event and the price range is wide. If you ever need to get a videography service, make sure you get multiple quotes before hiring a videographer. 

## Let Me Show Off a bit...
I am proud of SatRday LA because...

- We managed to pay for ALL essential and desired items while selling tickets at affordable prices (See Budgets and Finance)
- We were sold out and people came to the door to ask for more tickets
- We became a sponsor of SatRday Chicago 2019 :sunglasses:
- We can offer future SatRday LAs 
  - A logo
  - A conference planner made from a Googlesheet wedding planner
  - Lanyards! (we recycled lanyards)
  - Table cloth
  - Rolodex (well, not a physical one)
  - Lots of Sharpies! 

## Side Effects After SatRday LA
#### The Good Part
LA R community and fellow SatRday organizers around the world are awesome and very supportive! I learned a lot from fixing website, making google sheets/forms/docs, raising money, emailing etc. SatRday LA will (hopefully) be held annually in a different region of the Greater Los Angeles each year. We plan to rotate between regional organizers and please email [satrdays.losangeles@gmail.com](mailto:satrdays.losangeles@gmail.com) if you are interested in learning more. 

#### The Not-so-good Part
I still type SatRday instead of Saturday a lot of times. And iPhone autocorrect stopped working a long time ago. Before SatRday LA, I was not on Twitter. Now I am on Twitter too much... 
